@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTEXPORTMAILUTIL_H
-#define IMPORTEXPORTMAILUTIL_H
+#pragma once
 
 #include <KConfigGroup>
 #include "pimdataexportercore_private_export.h"
@@ -13,4 +12,3 @@ namespace ImportExportMailUtil {
 PIMDATAEXPORTER_TESTS_EXPORT void cleanupFolderSettings(KConfigGroup &oldGroup);
 }
 
-#endif // IMPORTEXPORTMAILUTIL_H
