@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PIMDATAEXPORTERCONFIGUREDIALOG_H
-#define PIMDATAEXPORTERCONFIGUREDIALOG_H
+#pragma once
 
 #include <KPageDialog>
 #ifdef WITH_KUSERFEEDBACK
@@ -32,4 +31,3 @@ private:
 #endif
 };
 
-#endif // PIMDATAEXPORTERCONFIGUREDIALOG_H
